/* eslint-disable class-methods-use-this */
import React, { Component } from 'react';
import { openTerminalWindow } from '@appirio/appirio/lib/tools/tools';
import { Field, SubmissionError } from 'redux-form';
import PropTypes from 'prop-types';
import _ from 'lodash';

const ipc = require('electron').ipcRenderer;

class NewProject extends Component {
  openExplorer() {
    const { change } = this.props;
    const { setProjectPath } = this.props.actions;
    ipc.send('open-file-dialog-for-file');
    ipc.on('selected-file', (event, path) => {
      if (path != null) {
        setProjectPath(path);
        change('newProjectPath', path);
      }
    });
  }

  displayTerminal(formData) {
    const formValues = {};
    _.forOwn(formData, (value, key) => {
      formValues[key] = value;
    });
    if (formValues.newProjectPath === null || formValues.newProjectPath === undefined || formValues.newProjectPath === '') {
      throw new SubmissionError({ _error: 'Please select a directory first..' });
    } else if (formValues.gitOriginURL === null || formValues.gitOriginURL === undefined || formValues.gitOriginURL === '') {
      throw new SubmissionError({ _error: 'Please provide a repository link.' });
    } else {
      openTerminalWindow(formValues.newProjectPath, formValues.gitOriginURL);
      throw new SubmissionError({ _error: '' });
    }
  }

  render() {
    const { handleSubmit, error } = this.props;
    return (
      <div className="container">
        <div className="justify-content-md-center row">
          <div className="col col-sm-auto" style={{ marginLeft: '20vw' }}>
            <form onSubmit={handleSubmit((formData) => this.displayTerminal(formData))} className="form-horizontal">
              <h1 className="new-proj"> Create a new project!</h1>
              <h4>Select the directory you'd like to create the new project in:</h4>
              <div style={{ justifyContent: 'center', alignItems: 'center' }}>
                <div style={{ marginBottom: '2vw' }}>
                  <div style={{ marginBottom: '2vw' }}>
                    <div style={{ display: 'inline-flex' }} >
                      <Field
                        name="newProjectPath"
                        className="form-control"
                        component="input"
                        type="text"
                        style={{ width: '30vw' }}
                        placeholder="Choose the parent folder for your new project"
                        pattern="(.*@.*:.*|https?://.*)"
                        readOnly
                      />
                    </div>
                    <button
                      className="btn btn-info"
                      type="button"
                      style={{ textAlign: 'left', marginLeft: '2vw' }}
                      onClick={() => this.openExplorer()}
                    >
                      Select Project Directory
                    </button>
                  </div>
                  <div>
                    <div>
                      <label>Create a new, empty Git project (in GitLab, for example) and paste the URL here:</label>
                    </div>
                    <div style={{ display: 'inline-flex' }}>
                      <Field
                        name="gitOriginURL"
                        className="form-control"
                        component="input"
                        type="text"
                        style={{ width: '30vw' }}
                        placeholder="https://gitlab.appirio.com/"
                        pattern="(.*@.*:.*|https?://.*)"
                      />
                    </div>
                  </div>
                </div>
                <div className="text-danger"><h5>{error && <strong>{error}</strong>}</h5></div>
                <div>
                  <button type="submit" className="btn btn-primary">Create the Project</button>
                  <div style={{ marginTop: '10px' }}>This will open a terminal window; follow the prompts.</div>
                </div>
              </div>
            </form>
          </div>
        </div>
      </div>
    );
  }
}

NewProject.propTypes = {
  change: PropTypes.func.isRequired,
  handleSubmit: PropTypes.func.isRequired,
  actions: PropTypes.objectOf(PropTypes.any).isRequired,
};

export default NewProject;
