import React from 'react';
import PropTypes from 'prop-types';
import ReactModal from 'react-modal';
import { remote } from 'electron';
import rollbar from '@appirio/appirio/lib/notify/rollbar';

const customStyles = {
  content: {
    border: '5px solid gray',
    background: 'white',
    overflow: 'auto',
    WebkitOverflowScrolling: 'touch',
    borderRadius: '4px',
    outline: 'none',
    padding: '1rem',
    top: '50%',
    left: '50%',
    right: 'auto',
    bottom: 'auto',
    marginRight: '-50%',
    width: '50%',
    transform: 'translate(-50%, -50%)',
  }
};

let prevError;

class ErrorBoundary extends React.Component {
  constructor(props) {
    super(props);
    this.hasError = false;
  }

  componentDidCatch(error, info) {
    this.hasError = true;
    this.error = error;
    this.severity = this.props.severity;

    const isNewError = (prevError === undefined || (error && prevError && error.toString() !== prevError.toString()));
    if (isNewError) {
      const errMessage = `${this.severity}: Caught Uncaught error\n${error.toString()}\n${info.componentStack}`;
      const payload = {
        context: 'uncaughtError',
      };
      rollbar.sendMessage(errMessage, true, payload);
      prevError = error;
    }
  }

  quitApp() {
    const window = remote.getCurrentWindow();
    if (this.severity === 'FATAL') {
      window.close();
    } else if (this.severity === 'CRITICAL') {
      window.reload();
    }
  }

  render() {
    if (this.hasError) {
      return (
        <div>
          <ReactModal
            isOpen={this.hasError}
            contentLabel="Error Modal"
            style={customStyles}
          >
            <div>
              <nav className="navbar navbar-dark errorModal">
                <span style={{
                  color: 'white', fontSize: '25px', verticalAlign: 'text-top', paddingLeft: '2%'
                }}
                >
                  Oops!
                </span>
              </nav>
              <span>
                <strong>
                  Something went wrong! We have notified the error to our developers. {this.severity === 'FATAL' ? 'Please restart the application.' : ''}
                </strong>
              </span>
              <span className="errorString">
                {this.error && this.error.toString()}
              </span>
              <div style={{
                textAlign: 'center',
              }}
              >
                <button onClick={() => this.quitApp()} className="quitAppButton">OK</button>
              </div>
            </div>
          </ReactModal>
        </div>
      );
    }

    return this.props.children;
  }
}

ErrorBoundary.propTypes = {
  severity: PropTypes.string.isRequired,
  children: PropTypes.objectOf(PropTypes.any).isRequired,
};

export default ErrorBoundary;
