import React, { Component } from 'react';
import { shell } from 'electron';
import { toolImages } from '@appirio/appirio/lib/tools/tools';
import ReactHtmlParser, { convertNodeToElement } from 'react-html-parser';
import PropTypes from 'prop-types';

class HavingTrouble extends Component {
  htmlParserTransform = (node, index) => {
    if (node.type === 'tag' && node.name === 'b') { // a tag named b
      const { href } = node.attribs; // extract the actual url
      return (
        <a
          href={href} // show it as the actual url, e.g. when hovered over, ..
          key={index}
          onClick={(event) => {
            event.preventDefault(); // .. but prevent the default behaviour
            // now, do whatever you want with href
            shell.openExternal(this.props.tool.platform.manualInstallUrl);
          }}
        >
          <span pointerEvents="none">
            {convertNodeToElement(node, index, this.htmlParserTransform)}
          </span>
        </a>
      );
    }
    if (node.type === 'tag' && node.name === 'ext') { // a tag named b
      const { href } = node.attribs; // extract the actual url
      return (
        <a
          href={href} // show it as the actual url, e.g. when hovered over, ..
          key={index}
          onClick={(event) => {
            event.preventDefault(); // .. but prevent the default behaviour
            // now, do whatever you want with href
            shell.openExternal(href);
          }}
        >
          <span pointerEvents="none">
            {convertNodeToElement(node, index, this.htmlParserTransform)}
          </span>
        </a>
      );
    }
  }

  render() {
    let tool = this.props.tool;
    return (
      <div>
        <div className="col-sm-3">
          <div className="card text-center settingsTool">
            <img className="card-img-top img-responsive" src={toolImages[tool.id]} alt={tool.name} />
            <div className="card-body">
              <h3 className="card-title">{tool.name}</h3>
              <div className="card-text">
                <span className="toolSpec"> {tool.installationstatus !== undefined ? tool.installationstatus : ''} </span>
              </div>
            </div>
          </div>
        </div>
        <div className="col-sm-4" style={{ paddingRight: '5%' }}>
          <h2>Install/Update Failed!</h2>
          <div>DiXie was not able to install/update the tool successfully for you. We received the following error:</div>
          <textarea className="text-danger installation-error" value={tool.installationError} readOnly />
        </div>
        <div className="col-sm-5">
          <h2>Help:</h2>
          <ol>
            {
              tool.platform.installationHelp !== undefined ?
                (tool.platform.installationHelp).map(helpCommand => {
                  return (
                    ReactHtmlParser(helpCommand, { transform: this.htmlParserTransform })
                  );
                }) : ''

            }
          </ol>
        </div>
      </div>
    );
  }
}

HavingTrouble.propTypes = {
  tool: PropTypes.objectOf(PropTypes.any).isRequired,
};

export default HavingTrouble;
