import React, { Component } from 'react';
import { Link } from 'react-router-dom';
import PropTypes from 'prop-types';
import ReactModal from 'react-modal';
import { practiceImages } from '@appirio/appirio/lib/tools/tools';
import ProjectsTile from '../containers/projects_tile';
import NewProject from '../containers/new_project';
import ProjectDetail from '../containers/project_detail';
import ErrorBoundary from './error-boundary';

const _ = require('lodash');
const imageToShowWhenNoProjects = require('../assets/no_projects.png');

class ProjectSection extends Component {
  componentDidMount() {
    ReactModal.setAppElement('#root');
    this.props.actions.refreshProjects(this.props.isShowingModal.showArchivedProjects, this.props.isShowingModal.sortField);
    this.props.actions.tabClick('projects');
  }

  handleClick() {
    this.props.actions.showNewProjectModal(true);
  }
  handleClose() {
    this.props.actions.showNewProjectModal(false);
    this.props.actions.refreshProjects(this.props.isShowingModal.showArchivedProjects, this.props.isShowingModal.sortField);
  }

  showArchivedProjects(currentValue) {
    this.props.actions.showArchivedProjects(currentValue, this.props.isShowingModal.sortField);
  }

  handleSortChange(event) {
    this.props.actions.sortProjects(event.target.value, this.props.isShowingModal.showArchivedProjects);
  }

  handleProjectDetailClick() {
    this.props.actions.showProjectDetailModal(true);
  }
  handleProjectDetailClose() {
    this.props.actions.showProjectDetailModal(false);
    this.props.actions.refreshProjects(this.props.isShowingModal.showArchivedProjects, this.props.isShowingModal.sortField);
  }

  render() {
    const customStyles = {
      content: {
        marginTop: '4vw'
      }
    };

    return (
      <div className="container section-container">
        <div className="wrapper">
          <Link className="btn btn-primary btn-md pull-right new-project text-center" to="" onClick={() => this.handleClick()}><span className="glyphicon glyphicon-plus" /> ADD PROJECT</Link>
        </div>

        <div className="wrapper projects-info row">
          <div className="displayInline">
            <div className="col-sm-3 sort-list">
              <h4 className="col-sm-3">Sort:</h4>
              <select className="col-sm-4 sortList" value={this.props.isShowingModal.sortField} onChange={(e) => this.handleSortChange(e)}>
                <option value="none">None</option>
                <option value="name">Name</option>
              </select>
            </div>
          </div>
          <div className="displayInline">
            <h4 className="archive col-sm-3"><input type="checkbox" className="archiveCheck" checked={this.props.isShowingModal.showArchivedProjects} onChange={() => this.showArchivedProjects(this.props.isShowingModal.showArchivedProjects)} /> Show Archived Projects</h4>
          </div>
          <div className="displayInline">
            <h4 className="col-sm-2 projects-size"><span> {_.size(this.props.projects)} Projects </span></h4>
          </div>
        </div>
        {this.props.projects !== undefined && _.size(this.props.projects) > 0 ?
          Object.keys(this.props.projects).map(project => (
            <ErrorBoundary severity="FATAL">
              <ProjectsTile project={this.props.projects[project]} key={this.props.projects[project].name} />
            </ErrorBoundary>)) :
          <div className="col-sm-offset-4 col-sm-4" style={{ opacity: '0.3' }}>
            <img src={imageToShowWhenNoProjects} alt="No Projects" />
            <h1 style={{ paddingLeft: '4vw' }}> We're off to a fresh start</h1>
          </div>
        }
        {
          this.props.isShowingModal.showNewProjectModal &&
          <ReactModal
            isOpen={this.props.isShowingModal.showNewProjectModal}
            contentLabel="Minimal Modal Example"
            style={customStyles}
          >
            <nav className="navbar navbar-dark modalNav">
              <button onClick={() => this.handleClose()} className="pull-right closeModal">CLOSE</button>
            </nav>
            <ErrorBoundary severity="CRITICAL">
              <NewProject />
            </ErrorBoundary>
          </ReactModal>
        }
        {
          this.props.isShowingModal.showProjectDetailModal &&
          <ReactModal
            isOpen={this.props.isShowingModal.showProjectDetailModal}
            contentLabel="Minimal Modal Example"
            style={customStyles}
          >
            <nav className="navbar navbar-dark modalNav">
              <button onClick={() => this.handleProjectDetailClose()} className="pull-right closeModal">CLOSE</button>
            </nav>
            <div className="col-sm-4">
              <div className="card text-center settingsTool">
                <img
                  className="card-img-top img-responsive"
                  src={practiceImages[(this.props.isShowingModal.project.type[0]).toLowerCase()]}
                  alt={this.props.isShowingModal.project.name}
                />
                <div className="card-body">
                  <h3 className="card-title">{this.props.isShowingModal.project.name}</h3>
                </div>
              </div>
            </div>
            <div className="col-sm-8">
              <ErrorBoundary severity="CRITICAL">
                <ProjectDetail selectedProject={this.props.isShowingModal.project} />
              </ErrorBoundary>
            </div>
          </ReactModal>
        }
      </div>
    );
  }
}

ProjectSection.propTypes = {
  projects: PropTypes.objectOf(PropTypes.any).isRequired,
  actions: PropTypes.objectOf(PropTypes.any).isRequired,
  isShowingModal: PropTypes.objectOf(PropTypes.any).isRequired,
};

export default ProjectSection;
