import React from 'react';
import { getServiceConfigFile, serviceLogos } from '@appirio/appirio/lib/servicesConfig/config_services';
import { shell } from 'electron';
import { Field } from 'redux-form';
import _ from 'lodash';
import PropTypes from 'prop-types';
import ReactHtmlParser, { convertNodeToElement } from 'react-html-parser';

class ServiceConfig extends React.Component {
  submitAccessToken(formData) {
    _.forOwn(formData, (settingValue, setting) => {
      if (setting === 'service') {
        getServiceConfigFile(this.props.service.name, settingValue.token, 'token');
        this.props.actions.getAccessToken(this.props.service.name, 'token', settingValue.token);
        if (settingValue.username !== undefined) {
          getServiceConfigFile(this.props.service.name, settingValue.username, 'username');
          this.props.actions.getAccessToken(this.props.service.name, 'username', settingValue.username);
        }
        this.props.actions.showServicesModal(false);
      }
    });
  }

  htmlParserTransform = (node, index) => {
    if (node.type == 'tag' && node.name == 'b') { // a tag named b
      const { href } = node.attribs; // extract the actual url
      return (
        <a
          href={href} // show it as the actual url, e.g. when hovered over, ..
          key={index}
          onClick={(event) => {
            event.preventDefault(); // .. but prevent the default behaviour
            //	now, do whatever you want with href
            shell.openExternal(this.props.service.token_url);
          }}
        >
          <span pointerEvents="none">
            {convertNodeToElement(node, index, this.htmlParserTransform)}
          </span>
        </a>
      );
    }
  }

  render() {
    const { handleSubmit, pristine, submitting } = this.props;
    let service = this.props.service;
    return (
      <div>
        <div className="col-sm-3">
          <div className="card text-center settingsTool">
            <img className="card-img-top img-responsive" src={serviceLogos[service.name]} alt={service.name} />
            <div className="card-body">
              <h3 className="card-title">{service.name}</h3>
              <a onClick={() => shell.openExternal(this.props.service.token_url)}>
                Go to {this.props.service.name}
              </a>
            </div>
          </div>
        </div>
        <div className="col-sm-4">
          <form onSubmit={handleSubmit((formData) => this.submitAccessToken(formData))} className="form-horizontal">
            {
              this.props.service.settings.map((setting) => {
                return (
                  <div key={setting.name}>
                    <div>
                      <label className="control-label" >{setting.name}</label>
                    </div>
                    <div>
                      {
                        setting.id === 'username' ?
                          <Field
                            name="service.username"
                            component="input"
                            type="text"
                            size="30"
                            placeholder={`Enter ${setting.name}`}
                          /> :
                          <Field
                            name="service.token"
                            component="input"
                            type="password"
                            size="30"
                            placeholder={`Enter ${setting.name}`}
                          />
                      }
                    </div>
                  </div>
                );
              })
            }

            <div style={{ marginTop: '2vw' }}>
              <button type="submit" className="btn btn-primary" disabled={pristine || submitting}>Submit</button>
            </div>
          </form>
        </div>
        <div className="col-sm-5 border">
          <h3>Help:</h3>
          {
            this.props.service.images.map((image) => {
              return (
                <div key={image.label}>
                  <div>
                    {ReactHtmlParser(
                      image.help_text,
                      { transform: this.htmlParserTransform }
                      )}
                  </div>
                  <img className="img-rounded img-responsive serviceImages" src={image.image} width="400px" height="300px" alt={image.label} />
                </div>
              );
            })
          }
        </div>
      </div >
    );
  }
}

ServiceConfig.propTypes = {
  service: PropTypes.objectOf(PropTypes.any).isRequired,
  actions: PropTypes.objectOf(PropTypes.any).isRequired,
};

export default ServiceConfig;
