import React, { Component } from 'react';
import ReactModal from 'react-modal';
import PropTypes from 'prop-types';
import ServiceLineItem from '../containers/services_item';
import ServicesConfig from '../containers/service_item_settings';
import ErrorBoundary from './error-boundary';

class Services extends Component {
  componentDidMount() {
    this.props.actions.tabClick('services');
  }

  handleClose() {
    this.props.actions.showServicesModal(false);
  }

  render() {
    const customStyles = {
      content: {
        marginTop: '4vw'
      }
    };
    return (
      <div className="container section-container">
        {
          Object.keys(this.props.services).map((service) => {
            return (
              <ErrorBoundary severity="FATAL">
                <ServiceLineItem service={this.props.services[service]} key={service} />
              </ErrorBoundary>
            );
          })
        }
        {
          this.props.isShowingModal.showServicesModal &&
          <ReactModal
            isOpen={this.props.isShowingModal.showServicesModal}
            contentLabel="Minimal Modal Example"
            style={customStyles}
          >
            <nav className="navbar navbar-dark modalNav">
              <button onClick={() => this.handleClose()} className="pull-right closeModal">CLOSE</button>
            </nav>
            <ErrorBoundary severity="CRITICAL">
              <ServicesConfig service={this.props.isShowingModal.service} />
            </ErrorBoundary>
          </ReactModal>
        }
      </div>
    );
  }
}

Services.propTypes = {
  services: PropTypes.objectOf(PropTypes.any).isRequired,
  actions: PropTypes.objectOf(PropTypes.any).isRequired,
  isShowingModal: PropTypes.objectOf(PropTypes.any).isRequired,
};

export default Services;
