/* eslint-disable no-else-return */
import React from 'react';
import PropTypes from 'prop-types';
import { setSetting, updateSetting } from '@appirio/appirio/lib/tools/tools';

class SettingsRow extends React.Component {
  setRecommendedValue(tool, component) {
    const oldValue = component.currentValue;
    this.props.actions.toolUpdateStart(tool, component);
    setSetting(tool, component)
      .then((setting) => {
        return this.props.actions.updateSettings(tool, setting);
      })
      .catch(err => {
        console.log('Error occurred while updating the recommended setting.');
        console.log(typeof err === 'string' ? err : err.toString());
        setTimeout(() => {
          component = updateSetting(tool, component, oldValue);
          this.props.actions.updateSettings(tool, component);
        }, 1000);
      });
  }

  render() {
    const settings = this.props.toolToDisplaySetting.platform.configuration.components;
    return Object.keys(settings).map((setting) => {
      const component = settings[setting];
      return (
        <tr key={component.item}>
          <td> {component.label} </td>
          {
            (typeof component.expected) === 'boolean' ?
              <td>{JSON.stringify(component.expected)}</td> :
              <td>{component.expected}</td>
          }
          <td>
            {
              <div>
                {(() => {
                  if (component.currentValue !== undefined && component.currentValue !== '') {
                    if (typeof component.currentValue === 'boolean') {
                      return <span>{JSON.stringify(component.currentValue)}</span>;
                    } else {
                      return <span>{component.currentValue}</span>;
                    }
                  } else {
                    return <span>-</span>;
                  }
                })()}
                {component.error !== undefined && component.error !== '' ? <div className="text-danger">{component.error}</div> : ''}
              </div>
            }
          </td>
          <td className="text-center">
            {
              (() => {
                if (component.validation) {
                  return <span className="glyphicon glyphicon-ok-sign" />;
                } else if (component.currentValue === 'Updating...') {
                  return <span>Updating...</span>;
                } else {
                  return (
                    <a className="changeSetting" onClick={() => this.setRecommendedValue(this.props.toolToDisplaySetting, component)}>
                      Change to {(typeof component.expected) === 'boolean' ? JSON.stringify(component.expected) : component.expected}?
                    </a>
                  );
                }
              })()
            }
          </td>
        </tr>
      );
    });
  }
}

SettingsRow.propTypes = {
  toolToDisplaySetting: PropTypes.objectOf(PropTypes.any).isRequired,
  actions: PropTypes.objectOf(PropTypes.any).isRequired,
};

export default SettingsRow;
