/* eslint-disable no-else-return */
import React, { Component } from 'react';
import { toolImages, checkSetting, checkConfigBeforeInstallation } from '@appirio/appirio/lib/tools/tools';
import { Link } from 'react-router-dom';
import { shell } from 'electron';
import ReactModal from 'react-modal';
import PropTypes from 'prop-types';

class ToolTile extends Component {
  componentDidMount() {
    ReactModal.setAppElement('#root');
    if (this.props.tool.installationstatus !== 'Not installed' &&
      this.props.tool.installationstatus !== 'Installing...' &&
      !this.props.tool.fulfillMinimumToolVersion &&
      this.props.tool.platform.configuration !== undefined) {
      checkSetting(this.props.tool)
        .then((settingMap) => {
          return this.props.actions.configSettings(this.props.tool, settingMap, this.props.tools);
        })
        .catch((err) => {
          console.log(err);
        });
    }
  }

  installation(tool, upgrade) {
    this.props.actions.ToolInstallStart(tool);
    const configStatus = checkConfigBeforeInstallation(tool.id, upgrade);
    return configStatus
      .then(installationResult => {
        if (typeof installationResult === 'object') {
          this.props.actions.ToolVersionUpdater(tool);
        } else {
          // if user denies or some error occurs during installation
          this.props.actions.ToolInstallationDenied(tool, installationResult);
        }
        return this.props.actions.toolStatusChecker();
      })
      .catch(err => {
        console.log(`Error occurred while installing tool "${tool.name}"`);
        const installationError = typeof err === 'string' ? err : err.toString();
        this.props.actions.ToolInstallationDenied(tool, installationError);
      });
  }

  handleClick(tool) {
    if (tool.installationstatus !== 'Not installed' && tool.installationstatus !== 'Installing...' && !tool.fulfillMinimumToolVersion) {
      this.props.actions.showModal(true, tool);
    }
  }
  handleClose() {
    this.props.actions.showModal(false);
  }

  handleTroubleClick(tool) {
    this.props.actions.showHavingTroubleModal(true, tool);
  }
  handleTroubleClose() {
    this.props.actions.showHavingTroubleModal(false);
  }

  disableToolWithDependencyNotInstalled() {
    const dependencies = this.props.tool.platform.dependencies;
    if (dependencies.length > 0) {
      for (let i = 0; i < dependencies.length; i++) {
        const currDependency = this.props.tools[dependencies[i]];
        if (currDependency !== undefined &&
          (currDependency.installationstatus === 'Not installed' ||
            currDependency.installationstatus === 'Installing...' ||
            currDependency.fulfillMinimumToolVersion ||
            (currDependency.counterForSettingsNotSet !== undefined &&
              currDependency.counterForSettingsNotSet > 0
            )
          )
        ) {
          return {
            backgroundColor: '#F0F0F0'
          };
        }
      }
    }
    return {};
  }

  render() {
    const tool = this.props.tool;
    const config = tool.platform.configuration;
    const dependencies = tool.platform.dependencies;
    let dependantTool;
    if (dependencies.length > 0) {
      for (let i = 0; i < dependencies.length; i++) {
        const currDependency = this.props.tools[dependencies[i]];
        if (currDependency !== undefined && (currDependency.installationstatus === 'Not installed' || currDependency.installationstatus === 'Installing...' || currDependency.fulfillMinimumToolVersion || (currDependency.counterForSettingsNotSet !== undefined && currDependency.counterForSettingsNotSet > 0))) {
          dependantTool = currDependency;
          break;
        }
      }
    }

    return (
      <div className="col-sm-4" >
        <div className="card text-center" onClick={() => this.handleClick(tool)} style={this.disableToolWithDependencyNotInstalled()} role="presentation">
          <div className="card-header">
            {
              config !== undefined && config.components !== undefined ?
                <span className="glyphicon glyphicon-cog pull-right">
                  {
                    tool.counterForSettingsNotSet !== undefined && tool.counterForSettingsNotSet > 0 ?
                      <span className="badge" style={{ backgroundColor: 'red' }}>{tool.counterForSettingsNotSet}</span> : ''
                  }
                </span>
                : ''
            }
          </div>
          <img className="card-img-top img-responsive" src={toolImages[tool.id]} alt={tool.name} />
          <div className="card-body">
            <h3 className="card-title">{tool.name}</h3>
            <div className="card-text">
              {
                (() => {
                  if (tool.installationstatus === 'Not installed') {
                    if (tool.id === 'brew') {
                      return <Link to="/tools" className="manualInstallUrlLink" onClick={() => shell.openExternal(tool.platform.manualInstallUrl)}>Install Manually</Link>;
                    } else if (dependantTool !== undefined && (dependantTool.installationstatus === 'Not installed' || dependantTool.installationstatus === 'Installing...')) {
                      return <span className="toolSpec">Install {dependantTool.name} first</span>;
                    } else if (dependantTool !== undefined && dependantTool.fulfillMinimumToolVersion) {
                      return <span className="toolSpec">Upgrade {dependantTool.name} first</span>;
                    } else if (dependantTool !== undefined && dependantTool.counterForSettingsNotSet !== undefined && dependantTool.counterForSettingsNotSet > 0) {
                      return <span className="toolSpec">Please complete Configuration Settings for {dependantTool.name} first</span>;
                    } else {
                      return (
                        <div style={{ display: 'inline-flex' }}>
                          <button className="btn btn-success install-button" onClick={() => this.installation(tool)}> Install </button>
                          {
                            (tool.installationstatus === 'Not installed' || tool.fulfillMinimumToolVersion || tool.recommendation) && tool.installationCounter > 0 ?
                              <Link to="/tools" className="install-button" style={{ padding: '0.5vw 0 0.5vw 2vw', display: 'block' }} onClick={() => this.handleTroubleClick(tool)}>
                                Having trouble?
                              </Link> :
                              ''
                          }
                        </div>
                      );
                    }
                  } else if (tool.installationstatus === 'Installing...') {
                    return (
                      <span className="toolSpec"> <strong>Installing...</strong> <span className="glyphicon glyphicon-refresh glyphicon-refresh-animate" />
                        <div>This may take some time. Please DON&#39;T quit the application.</div>
                      </span>);
                  } else {
                    let upgradeElement;
                    if (tool.recommendation && tool.installationstatus !== 'Installing...' && tool.installationstatus !== 'Not installed') {
                      upgradeElement = <button className="btn btn-warning" onClick={() => this.installation(tool, true)}> Upgrade </button>;
                    } else {
                      upgradeElement = '';
                    }
                    console.log(tool.id, tool.recommendation, tool.installationCounter);
                    return (
                      <div>
                        <span className="toolSpec"> {tool.installationstatus !== undefined ? tool.installationstatus : ''} </span>
                        {upgradeElement}
                        {
                          tool.recommendation && tool.installationCounter > 0 ?
                            <Link to="/tools" className="install-button" style={{ padding: '0.5vw 0 0.5vw 6.5vw', display: 'table-cell' }} onClick={() => this.handleTroubleClick(tool)}>
                              Having trouble?
                            </Link> :
                            ''
                        }
                      </div>
                    );
                  }
                })()
              }
            </div>
          </div>
        </div>
      </div >
    );
  }
}

ToolTile.propTypes = {
  tool: PropTypes.objectOf(PropTypes.any).isRequired,
  actions: PropTypes.objectOf(PropTypes.any).isRequired,
  tools: PropTypes.objectOf(PropTypes.any).isRequired
};

export default ToolTile;
