import React, { Component } from 'react';
import ReactModal from 'react-modal';
import PropTypes from 'prop-types';
import { toolImages } from '@appirio/appirio/lib/tools/tools';
import ToolTile from '../containers/tool_row';
import ToolSettings from '../containers/setting';
import HavingTrouble from './having_trouble';
import ErrorBoundary from './error-boundary';

class ToolsSection extends Component {
  componentDidMount() {
    this.props.actions.toolStatusChecker();
    this.props.actions.tabClick('tools');
  }

  handleClick() {
    this.props.actions.showModal(true);
  }
  handleClose() {
    this.props.actions.showModal(false);
    this.props.actions.toolStatusChecker();
  }

  handleTroubleClick() {
    this.props.actions.showHavingTroubleModal(true);
  }
  handleTroubleClose() {
    this.props.actions.showHavingTroubleModal(false);
  }

  render() {
    let tool = this.props.isShowingModal.tool;
    const customStyles = {
      content: {
        marginTop: '4vw'
      }
    };
    return (
      <div className="container section-container">
        <div className="row">
          {
            Object.keys(this.props.tools).map((toolName) => {
              return (
                <ErrorBoundary severity="FATAL">
                  <ToolTile tool={this.props.tools[toolName]} key={toolName} />
                </ErrorBoundary>
              );
            })
          }
        </div>
        {
          this.props.isShowingModal.showModal &&
          <ReactModal
            isOpen={this.props.isShowingModal.showModal}
            contentLabel="Configuration Settings"
            style={customStyles}
          >
            <nav className="navbar navbar-dark modalNav">
              <button onClick={() => this.handleClose()} className="pull-right closeModal">CLOSE</button>
            </nav>
            <div className="col-sm-3">
              <div className="card text-center settingsTool">
                <img className="card-img-top img-responsive" src={toolImages[tool.id]} alt={tool.name} />
                <div className="card-body">
                  <h3 className="card-title">{tool.name}</h3>
                  <div className="card-text">
                    <span className="toolSpec"> {tool.installationstatus !== undefined ? tool.installationstatus : ''} </span>
                  </div>
                </div>
              </div>
            </div>
            <div className="col-sm-9">
              <ErrorBoundary severity="CRITICAL">
                <ToolSettings tool={tool} />
              </ErrorBoundary>
            </div>
          </ReactModal>
        }
        {
          this.props.isShowingModal.showHavingTroubleModal &&
          <ReactModal
            isOpen={this.props.isShowingModal.showHavingTroubleModal}
            contentLabel="Having Trouble"
            style={customStyles}
          >
            <nav className="navbar navbar-dark modalNav">
              <button onClick={() => this.handleTroubleClose()} className="pull-right closeModal">CLOSE</button>
            </nav>
            <ErrorBoundary severity="CRITICAL">
              <HavingTrouble tool={tool} />
            </ErrorBoundary>
          </ReactModal>
        }
      </div>
    );
  }
}

ToolsSection.propTypes = {
  isShowingModal: PropTypes.objectOf(PropTypes.any).isRequired,
  actions: PropTypes.objectOf(PropTypes.any).isRequired,
  tools: PropTypes.objectOf(PropTypes.any).isRequired,
};

export default ToolsSection;
