import React from 'react';
import { Field, SubmissionError } from 'redux-form';
import PropTypes from 'prop-types';
import { practiceImages } from '@appirio/appirio/lib/tools/tools';
import ErrorBoundary from './error-boundary';
import CheckboxGroup from './CheckboxGroup';

class UserSettings extends React.Component {
  componentDidMount() {
    this.props.tabClick('usersettings');
  }

  onSubmit(values) {
    if (!values.firstName || !values.lastName || !values.email || !values.username) {
      throw new SubmissionError({ _error: 'All fields are mandatory !' });
    } else if (values.practice.length <= 0) {
      throw new SubmissionError({ _error: 'Select at least one practice!' });
    } else {
      this.props.history.push('/');
      this.props.updateUserSetting(values);
    }
  }

  render() {
    const options = [
      { label: 'Salesforce', value: 'salesforce', img: practiceImages.salesforce },
      { label: 'Google', value: 'google', img: practiceImages.google }
    ];

    const { handleSubmit, submitting, error } = this.props;
    return (
      <div className="section-container">
        <div style={{ padding: '1% 0 1% 10%' }}>
          <h1>Welcome!</h1>
          <h1>Let's start with a few basics.</h1>
        </div>
        <ErrorBoundary severity="FATAL">
          <form onSubmit={handleSubmit(this.onSubmit.bind(this))} className="form-horizontal">
            <div className="row user-settings">
              <div className="col-sm-6">
                <div className="form-group" >
                  <label className="control-label col-sm-offset-2 col-sm-3">First Name:</label>
                  <div className="col-sm-4" >
                    <Field
                      name="firstName"
                      className="form-control"
                      component="input"
                      type="text"
                      placeholder="First Name"
                    />
                  </div>
                </div>
                <div className="form-group user-settings-form" >
                  <label className="control-label col-sm-offset-2 col-sm-3" >Last Name:</label>
                  <div className="col-sm-4" >
                    <Field
                      name="lastName"
                      className="form-control"
                      component="input"
                      type="text"
                      placeholder="Last Name"
                    />
                  </div>
                </div>
                <div className="form-group" >
                  <label className="control-label col-sm-offset-2 col-sm-3" >Email:</label>
                  <div className="col-sm-4" >
                    <Field
                      name="email"
                      className="form-control"
                      component="input"
                      type="email"
                      placeholder="dixie@appirio.com"
                    />
                  </div>
                </div>
                <div className="form-group" >
                  <label className="control-label col-sm-offset-2 col-sm-3" >Shortname:</label>
                  <div className="col-sm-4" >
                    <Field
                      name="username"
                      className="form-control"
                      component="input"
                      type="text"
                      placeholder="dixie"
                    />
                  </div>
                </div>
              </div>
              <div className="col-sm-6">
                <div className="form-group" >
                  <div>
                    <label className="practiceChoice"> Which practice do you belong to ? </label>
                  </div>
                  <CheckboxGroup name="practice" options={options} />
                </div>
              </div>
            </div>
            <div className="text-danger text-center"><h5>{error && <strong>{error}</strong>}</h5></div>
            <div className="form-group row" >
              <div className="submit-user-setting" style={{ marginTop: '2%' }}><button type="submit" className="btn btn-primary" disabled={submitting}>Submit</button></div>
            </div>
          </form>
        </ErrorBoundary>
      </div >
    );
  }
}

UserSettings.propTypes = {
  history: PropTypes.objectOf(PropTypes.any).isRequired,
  tabClick: PropTypes.func.isRequired,
  updateUserSetting: PropTypes.func.isRequired,
  handleSubmit: PropTypes.func.isRequired,
};

export default UserSettings;
