/* eslint-disable indent */
import { readUserConfig, hasUserConfig } from '@appirio/appirio/lib/config/config';

const _ = require('lodash');

const projectList = hasUserConfig('projects') ? readUserConfig('projects') : [];
const projectMap = _.mapKeys(projectList, 'path');

export default function(state = projectMap, action) {
  switch (action.type) {
    case 'PROJECT_ARCHIVE':
      {
        const currentState = { ...state };
        currentState[action.project.path].archived = action.payload;
        return currentState;
      }
    case 'SHOW_ARCHIVE':
      {
        let archiveState = _.orderBy(action.projects, [action.sortField], ['asc']);
        if (action.payload) {
          archiveState = _.filter(archiveState, (val, key) => {
            return val.archived === !action.payload;
          });
        }
        archiveState = _.mapKeys(archiveState, 'path');
        return archiveState;
      }
    case 'SORT_PROJECTS':
      {
        let sortState = action.projects;
        sortState = _.orderBy(sortState, [action.payload], ['asc']);
        if (!action.showArchivedProjects) {
          sortState = _.filter(sortState, (val, key) => {
            return val.archived === action.showArchivedProjects;
          });
        }
        const sortedMap = _.mapKeys(sortState, 'path');
        return sortedMap;
      }
    case 'REFRESH_PROJECTS':
      {
        let newProjectMap = _.orderBy(action.payload, [action.sortField], ['asc']);
        if (!action.showArchivedProjects) {
          newProjectMap = _.filter(newProjectMap, (val, key) => {
            return val.archived === action.showArchivedProjects;
          });
        }
        newProjectMap = _.mapKeys(newProjectMap, 'path');
        return newProjectMap;
      }
    default:
      return state;
  }
}
