/* eslint-disable indent */
import { mapOfTools } from '@appirio/appirio/lib/tools/tools';
import {
  TOOL_CHECKER,
  TOOL_VERSION_CHANGED,
  TOOL_INSTALL_START,
  UPDATE_SETTING_START,
  CONFIG_SETTING,
  UPDATE_SETTING,
  TOOL_INSTALLATION_DENIED
} from '../actions/index';

const _ = require('lodash');

const installingTools = [];

export default function(state = mapOfTools, action) {
  switch (action.type) {
    case TOOL_CHECKER:
      {
        const currentState = action.payload;
        if (installingTools.length > 0) {
          Object.keys(currentState).map((tool) => {
            if (installingTools.includes(tool)) {
              currentState[tool].installationstatus = 'Installing...';
            }
          });
        }
        return currentState;
      }
    case TOOL_INSTALL_START:
      {
        const newMapOfTools = { ...state };
        installingTools.push(action.payload.id);
        newMapOfTools[action.payload.id].installationstatus = 'Installing...';
        return newMapOfTools;
      }
    case TOOL_VERSION_CHANGED:
      {
        const changedMapOfTools = { ...state };
        changedMapOfTools[action.payload.id] = action.payload;
        _.remove(installingTools, (toolId) => {
          return toolId === action.payload.id;
        });
        return changedMapOfTools;
      }
    case TOOL_INSTALLATION_DENIED:
      {
        const deniedToolState = { ...state };
        if (deniedToolState[action.payload.id].installationstatus === undefined ||
          deniedToolState[action.payload.id].installationstatus === 'Installing...') {
          deniedToolState[action.payload.id].installationstatus = 'Not installed';
        }
        if (deniedToolState[action.payload.id].platform.manualInstallUrl !== undefined) {
          deniedToolState[action.payload.id].manualInstallation = true;
        }
        _.remove(installingTools, (toolId) => {
          return toolId === action.payload.id;
        });
        return deniedToolState;
      }
    case CONFIG_SETTING:
      {
        const settingsState = { ...state };
        settingsState[action.payload.id].platform.configuration.components = action.setting;
        return settingsState;
      }
    case UPDATE_SETTING_START:
      {
        const newState = { ...state };
        const settingToUpdate = newState[action.payload.id]['platform']['configuration']['components'][action.settings.item];
        settingToUpdate.currentValue = 'Updating...';
        if (settingToUpdate.error !== undefined) {
          settingToUpdate.error = '';
        }
        return newState;
      }
    case UPDATE_SETTING:
      {
        const updatedSettingsStateTool = { ...state };
        updatedSettingsStateTool[action.payload.id]['platform']['configuration']['components'][action.settings.item] = action.settings;
        return updatedSettingsStateTool;
      }
    default:
      return state;
  }
}
